@@ -15,6 +15,17 @@ async def run_monitoring_tasks(
     async_queue: asyncio.Queue,
     config: dict,
 ):
+    """Matches tasks to sensors and does the acutal monitoring.
+
+    Args:
+        sensors_avail (list): List of available sensors.
+        taskdata (list): List of tasks from the PRTG Core.
+        prtg_api (PRTGHTTPApi): A PRTG HTTP API object.
+        snmp_engine (SnmpEngine): SNMP Engine object.
+        async_queue (asyncio.Queue): An AsyncIO Queue.
+        config (dict): The probe config as dict.
+
+    """
     monitoring_task_list = []
     task_chunk_size = int(config["probe_task_chunk_size"])
     task_chunks = [taskdata[x : x + task_chunk_size] for x in range(0, len(taskdata), task_chunk_size)]
@@ -44,6 +55,19 @@ async def run_monitoring_tasks(
 async def monitoring(
     tasks_list: list, sensor_objects: list, prtg_api: PRTGHTTPApi, snmp_engine: SnmpEngine, config: dict
 ):
+    """
+    An additional wrapper around ``run_monitoring_tasks``
+    Args:
+        tasks_list (list):
+        sensor_objects (list):
+        prtg_api (PRTGHTTPApi): A PRTG HTTP API object.
+        snmp_engine (SnmpEngine): SNMP Engine object.
+        config (dict):
+
+    Returns:
+        list: A list of monitoring results
+
+    """
     logging.info("Initializing Queue")
     async_queue = asyncio.Queue()
 
