@@ -16,6 +16,16 @@ from prtg_pyprobe.utils.sensor_loader import create_sensor_objects
 async def monitoring_loop(
     prtg_api: PRTGHTTPApi, sensors: list, snmp_eng: SnmpEngine, run_monitoring: bool, config: dict
 ):
+    """The monitoring functionality of the pyprobe.
+
+    Args:
+        prtg_api (PRTGHTTPApi): PRTGHTTPApi object.
+        sensors (list): List of sensor objects.
+        snmp_eng (SnmpEngine): SNMP Engine object.
+        run_monitoring (bool): Bool which determines whether to run monitoring or not.
+        config (dict): Probe configuration as dict.
+
+    """
     while run_monitoring:
         tasks_api_response = await prtg_api.get_tasks()
         if tasks_api_response.status_code == 200:
@@ -29,11 +39,14 @@ async def monitoring_loop(
                     prtg_api=prtg_api,
                     config=config,
                 )
+        if tasks_api_response.status_code == 401:
+            logging.warning("Please check that your probe has been approved in PRTG!")
         if await asyncio.sleep(10):
             break
 
 
 def main():
+    """The pyprobe main function."""
     logger, console_handler, formatter = setup_logging()
     logger.info("Starting pyprobe!")
     try:
