@@ -1,5 +1,7 @@
 import logging
 from abc import ABC
+from collections import namedtuple
+from typing import Union
 
 import psutil
 from pysnmp.error import PySnmpError
@@ -17,28 +19,58 @@ from prtg_pyprobe.sensors.helpers import SensorDefinitionGroup
 
 
 class SensorBase(ABC):
+    """Abstract Base Class, from which every sensor should inherit."""
+
     def __getitem__(self, kind):
         return self.kind
 
     @property
     def name(self) -> str:
+        """Abstract property name of SensorBase.
+
+        Raises:
+            NotImplementedError: Has to be overwritten in implementation
+        """
         raise NotImplementedError
 
     @property
     def kind(self) -> str:
+        """Abstract property kind of SensorBase.
+
+        Raises:
+            NotImplementedError: Has to be overwritten in implementation
+        """
         raise NotImplementedError
 
     @property
     def definition(self) -> dict:
+        """Abstract property definition of SensorBase.
+
+        Raises:
+            NotImplementedError: Has to be overwritten in implementation
+        """
         raise NotImplementedError
 
     async def work(self, *args, **kwargs) -> None:
+        """Abstract method work of SensorBase.
+
+        Args:
+            *args:
+            **kwargs:
+
+        Raises:
+            NotImplementedError: Has to be overwritten in implementation
+
+        """
         raise NotImplementedError
 
 
 class SensorPSUtilBase(SensorBase, ABC):
+    """Base class for all sensors utilizing `psutil`."""
+
     @property
     def temperature_settings_group(self):
+        """Add Group and Field for temperature settings"""
         probe_health_def_group_temperature = SensorDefinitionGroup(name="temperature", caption="Temperature Settings")
         probe_health_def_group_temperature.add_field(
             field_type="radio",
@@ -52,6 +84,7 @@ class SensorPSUtilBase(SensorBase, ABC):
 
     @property
     def diskspace_settings_group(self):
+        """Add Group and Field for diskspace settings"""
         probe_health_def_group_diskspace = SensorDefinitionGroup(name="diskspace", caption="Disk Space Settings")
         probe_health_def_group_diskspace.add_field(
             field_type="radio",
@@ -64,7 +97,15 @@ class SensorPSUtilBase(SensorBase, ABC):
         return probe_health_def_group_diskspace
 
     @staticmethod
-    def get_system_temperatures(fahrenheit):
+    def get_system_temperatures(fahrenheit: bool) -> Union[dict, None]:
+        """Get system temperature.
+
+        Args:
+            fahrenheit (bool): Use Fahrenheut or Celcius as unit.
+
+        Returns:
+            Union: Return either a dict or None.
+        """
         if not hasattr(psutil, "sensors_temperatures"):
             return None
         temperatures = psutil.sensors_temperatures(fahrenheit=fahrenheit)
@@ -74,28 +115,56 @@ class SensorPSUtilBase(SensorBase, ABC):
         return temperatures
 
     @staticmethod
-    def get_system_partitions():
+    def get_system_partitions() -> list:
+        """Get partitions.
+
+        Returns:
+            list: A list of partitions.
+        """
         return psutil.disk_partitions()
 
     @staticmethod
-    def get_partition_usage(partition):
+    def get_partition_usage(partition: list) -> namedtuple:
+        """Get disk usage of partitions.
+
+        Args:
+            partition (list): A list of partitions.
+
+        Returns:
+            namedtuple: A named tuple containing disk usage data.
+
+        """
         return psutil.disk_usage(partition[1])
 
     @staticmethod
-    def get_memory_usage():
+    def get_memory_usage() -> tuple:
+        """Get memory usage.
+
+        Returns:
+            tuple: A tuple containing virtual memory and swap usage.
+
+        """
         vmemory = psutil.virtual_memory()
         swapmemory = psutil.swap_memory()
 
         return vmemory, swapmemory
 
     @staticmethod
-    def get_cpu_load():
+    def get_cpu_load() -> tuple:
+        """Get CPU load average.
+
+        Returns:
+            tuple: A tuple containing the load average.
+        """
         return psutil.getloadavg()
 
 
 class SensorSNMPBase(SensorBase, ABC):
+    """Base class for all SNMP sensors."""
+
     @property
     def snmp_specific_settings_group(self):
+        """Add Group and Field for SNMP related settings."""
         snmp_group_snmp_specifications = SensorDefinitionGroup(name="snmpspecific", caption="SNMP Specific")
         snmp_group_snmp_specifications.add_field(
             field_type="edit",
@@ -131,6 +200,22 @@ class SensorSNMPBase(SensorBase, ABC):
         engine: SnmpEngine = SnmpEngine(),
         context: ContextData = ContextData(),
     ) -> list:
+        """SNMP single get.
+
+        Args:
+            target (str): The target of the SNMP request.
+            oids (list): A list of OIDs to query.
+            credentials (CommunityData): The PySnmp authentication data.
+            port (int): The port the target listens for SNMP requests.
+            engine (SnmpEngine): PySnmp SNMP Engine.
+            context (ContextData): PySnmp context data
+
+        Returns:
+            list: A list of OIDs and values.
+
+        Raises:
+            PySnmpError: Raised when something goes wrong.
+        """
         (error_indication, error_status, error_index, var_binds,) = await pysnmp_asyncio.getCmd(
             engine,
             credentials,
@@ -156,6 +241,22 @@ class SensorSNMPBase(SensorBase, ABC):
         engine: SnmpEngine = SnmpEngine(),
         context: ContextData = ContextData(),
     ):
+        """SNMP bulk get (getnext).
+
+        Args:
+            target (str): The target of the SNMP request.
+            oids (list): A list of OIDs to query.
+            credentials (CommunityData): The PySnmp authentication data.
+            port (int): The port the target listens for SNMP requests.
+            engine (SnmpEngine): PySnmp SNMP Engine.
+            context (ContextData): PySnmp context data
+
+        Returns:
+            list: A list of OIDs and values.
+
+        Raises:
+            PySnmpError: Raised when something goes wrong.
+        """
         # todo:  Probably we won't need bulk get
         result = []
         var_binds = self.construct_object_types(oids)
@@ -197,13 +298,30 @@ class SensorSNMPBase(SensorBase, ABC):
 
     @staticmethod
     def construct_object_types(list_of_oids: list) -> list:
+        """Construnc objects from given OIDs
+
+        Args:
+            list_of_oids: A list of OIDs.
+
+        Returns:
+            list: A list of PySnmp Object Identities.
+
+        """
         object_types = []
         for oid in list_of_oids:
             object_types.append(ObjectType(ObjectIdentity(oid)))
         return object_types
 
     @staticmethod
-    def cast(value):
+    def cast(value: str) -> Union[str, float, int]:
+        """A brute force cast method.
+
+        Args:
+            value (str): A string.
+
+        Returns:
+            Union: A hopefully cast value.
+        """
         try:
             return int(value)
         except (ValueError, TypeError):
