@@ -47,9 +47,11 @@ class Sensor(SensorBase):
 
     async def work(self, task_data: dict, q: asyncio.Queue) -> None:
         port_data = SensorData(sensor_id=task_data["sensorid"])
+        connection_timeout = int(task_data.get("timeout", 2))
         try:
             start_time = time.time()
-            reader, writer = await asyncio.open_connection(host=task_data["host"], port=int(task_data["targetport"]))
+            connection = asyncio.open_connection(host=task_data["host"], port=int(task_data["targetport"]))
+            reader, writer = await asyncio.wait_for(connection, timeout=connection_timeout)
             writer.close()
             await writer.wait_closed()
             end_time = time.time()
@@ -62,14 +64,15 @@ class Sensor(SensorBase):
                 kind="TimeResponse",
                 value=float(response_time),
             )
-        except ConnectionError:
+        except (TimeoutError, asyncio.TimeoutError, ConnectionError, socket.gaierror):
             port_data.error = "Exception"
             port_data.error_code = 1
             port_data.message = "Port check failed. See log for details"
-            logging.exception("There has been a connection error.")
-        except socket.gaierror:
-            port_data.error = "Exception"
-            port_data.error_code = 1
-            port_data.message = "Port check failed. See log for details"
-            logging.exception("There has been a connection error.")
+            logging.exception(
+                "There has been a connection error - host:{} - port:{}".format(
+                    task_data["host"], task_data["targetport"]
+                )
+            )
+
         await q.put(port_data.data)
+        q.task_done()
