@@ -14,7 +14,7 @@ from prtg_pyprobe.sensors.sensor import SensorBase
 class Sensor(SensorBase):
     @property
     def name(self) -> str:
-        return "Traffic"
+        return "Traffic (Probe)"
 
     @property
     def kind(self) -> str:
@@ -27,7 +27,7 @@ class Sensor(SensorBase):
             kind=self.kind,
             description="Monitors traffic on the host the probe is running on.",
             sensor_help="Monitors traffic on the host the probe is running on. "
-            "This is always the case even if added to a different device than Probe Device.",
+            "This is always the case even if added to a different device than the Probe Device.",
             tag="mptrafficsensor",
         )
         traffic_def_group_sensor_specific = SensorDefinitionGroup(name="sensor_specific", caption="Sensor Specific")
