@@ -18,6 +18,15 @@ from prtg_pyprobe.utils.validators import (
 
 class IPDNSValidator(Validator):
     def validate(self, document):
+        """Check if input is a IP address or DNS name.
+
+        Args:
+            document: ``prompt`` toolkit document.
+
+        Raises:
+            ValidationError: If the document does not match validation rule.
+
+        """
         ip_dns_ok = regex.match(
             r"^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$|"
             r"^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)+([A-Za-z]|[A-Za-z][A-Za-z0-9\-]*[A-Za-z0-9])$",
@@ -32,6 +41,15 @@ class IPDNSValidator(Validator):
 
 class DirectoryWriteableValidator(Validator):
     def validate(self, document):
+        """Check if input directory is writeable.
+
+        Args:
+            document: ``prompt`` toolkit document.
+
+        Raises:
+            ValidationError: If the document does not match validation rule.
+
+        """
         if document.text:
             try:
                 os.chdir(Path(document.text).parent)
@@ -54,6 +72,15 @@ class DirectoryWriteableValidator(Validator):
 
 class PortRangeValidator(Validator):
     def validate(self, document):
+        """Check if integer is between 1 and 65535.
+
+        Args:
+            document: ``prompt`` toolkit document.
+
+        Raises:
+            ValidationError: If the document does not match validation rule.
+
+        """
         port_ok = True
         try:
             port_number = int(document.text)
@@ -70,6 +97,15 @@ class PortRangeValidator(Validator):
 
 class GUIDValidator(Validator):
     def validate(self, document):
+        """Check if string is valid GUID.
+
+        Args:
+            document: ``prompt`` toolkit document.
+
+        Raises:
+            ValidationError: If the document does not match validation rule.
+
+        """
         guid_ok = regex.match(
             r"([a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}){1}",
             document.text,
@@ -83,6 +119,15 @@ class GUIDValidator(Validator):
 
 class BaseIntervalValidator(Validator):
     def validate(self, document):
+        """Check if input interval is between 60 and 300 seconds.
+
+        Args:
+            document: ``prompt`` toolkit document.
+
+        Raises:
+            ValidationError: If the document does not match validation rule,
+
+        """
         interval_ok = True
         try:
             interval = int(document.text)
@@ -115,19 +160,52 @@ class BaseChunkSizeValidator(Validator):
 
 class NotEmptyValidator(Validator):
     def validate(self, document):
+        """Check if input is empty.
+
+        Args:
+            document: ``prompt`` toolkit document.
+
+        Raises:
+            ValidationError: If the document does not match validation rule.
+
+        """
         if document.text == "":
             raise ValidationError(message="Input cannot be empty.", cursor_position=len(document.text))
 
 
 class ProbeConfig(object):
-    def __init__(self, path):
+    """An object representing the probe config providing read and write functions."""
+
+    def __init__(self, path: str):
+        """Constructor of ProbeConfig.
+
+        Args:
+            path (str): The path to the config file.
+
+        """
         self.config_path = path
 
-    def write(self, config_data):
+    def write(self, config_data: dict):
+        """Write the given config data to the path provided to the constructor.
+
+        Args:
+            config_data (dict): Config data as dict.
+
+        """
         with open(self.config_path, "w") as f:
             yaml.dump(config_data, f)
 
-    def read(self):
+    def read(self) -> dict:
+        """Read the config from file or ENV.
+
+        Returns:
+            dict: Config as dict.
+
+        Raises:
+            ValidationFailedError: Is raised when config can not be validated.
+            KeyError: Is raised when there is no config in the ENV.
+
+        """
         try:
             with open(self.config_path, "r") as f:
                 config = yaml.load(f, Loader=yaml.FullLoader)
