@@ -1,4 +1,5 @@
 import functools
+from typing import Any
 
 from cerberus import Validator
 
@@ -108,18 +109,38 @@ validation_schemes = {
 
 
 class ValidationFailedError(Exception):
+    """Raised when validation against scheme failed."""
+
     def __init__(self, validator):
+        """Constructor of ValidationFailedError.
+
+        Args:
+            validator (cerberus.validator): Cerberus validator.
+
+        """
         self._validator = validator
         self._message = self._validator.errors
         super().__init__(self._message)
 
 
 class ValidationNotPossibleError(Exception):
+    """Raised when validation is not possible."""
+
     def __init__(self):
         super().__init__("Cannot validate, no validation schema defined.")
 
 
-def validate(func):
+def validate(func: Any):
+    """Decorator to validate dictionaries.
+
+    Args:
+        func (Any): Decorated function.
+
+    Returns:
+        Any: Wrapped function.
+
+    """
+
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
         value = func(*args, **kwargs)
@@ -133,6 +154,18 @@ def validate(func):
 
 
 def validation(val: dict, scheme: dict) -> dict:
+    """Validation of a dict against a cerberus scheme.
+
+    Args:
+        val (dict): Input dictionary.
+        scheme (dict): Cerberus validation scheme.
+
+    Returns:
+        dict: Input dictionary if validation succeeded.
+
+    Raises:
+        ValidationFailedError: Raised if the validation fails.
+    """
     v = Validator(scheme)
     if v.validate(val):
         return val
