@@ -20,6 +20,7 @@ from prtg_pyprobe.sensors import (
     sensor_probe_diskspace,
     sensor_external_ip,
     sensor_cpuload,
+    sensor_s3_bucket_total,
 )
 from prtg_pyprobe.sensors.helpers import (
     SensorDefinition,
@@ -215,6 +216,11 @@ def cpu_load_sensor():
     return sensor_cpuload.Sensor()
 
 
+@pytest.fixture()
+def s3_total_sensor():
+    return sensor_s3_bucket_total.Sensor()
+
+
 @pytest.fixture()
 def snmp_custom_sensor_taskdata():
     return {
